from blueqat.pauli import qubo_bit

def qubo_to_pauli(qubo):
    h = 0.0
    assert all(len(q) == len(qubo) for q in qubo)
    for i in range(len(qubo)):
        h += qubo_bit(i) * qubo[i][i]
        for j in range(i + 1, len(qubo)):
            h += qubo_bit(i)*qubo_bit(j) * (qubo[i][j] + qubo[j][i])
    return h



import setuptools

with open("README.rst", "r") as f:
    long_description = f.read()

with open("wildblue/_version.py", "r") as f:
    exec(f.read())

setuptools.setup(
    name = "wildblue",
    version=__version__,
    author="MDR Inc.",
    author_email="kato@mdrft.com",
    description="Interface between wildqat and blueqat",
    long_description=long_description,
    long_description_content_type="text/x-rst",
    url="https://github.com/mdrft/wildblue",
    license="Apache 2",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: Apache Software License",
        "Development Status :: 3 - Alpha",
    ]
)
